use DE_EPAGES::AmazonPayments::API::DTO::AddressInfo;
use DE_EPAGES::AmazonPayments::API::Payment qw ( StoreAmazonShippingAddress );
use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Database::API::Connection qw ( GetTestSite RunOnStore );
use DE_EPAGES::Test::Mock::EpagesObject;
use Test::More tests => 6;

use strict;

RunScript(
    Message => 'long',
    Sub     => sub {
        RunOnStore(
            'Store' => GetTestSite(),
            'Sub'   => sub {
                my $User = DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Permission::API::Object::User', {});
                my $Basket = DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::Order::API::Object::Basket', {
                    User => $User,
                    BillingAddress => undef,
                } );
                $Basket->mock('updateTaxArea', sub { pass('update tax area') });
                $Basket->mock('updateTaxAreaDigital', sub { pass('update tax area digital') });
                $Basket->mock('container', sub { undef });
                $User->mock('folder', sub {
                    my $Folder = DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Object::API::Object::Object', {});
                    $Folder->mock('insertChild', sub { return DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Address::API::Object::Address', $_[2]); });
                    $Folder->mock('nextAlias', sub { return 'next Alias' });
                    return $Folder;
                });
                ok( StoreAmazonShippingAddress( $Basket, {} ), 'initial StoreAmazonShippingAddress causes an update.' );
                ok( $Basket->get('BillingAddress'), 'BillingAddress not null anymore.');
                is( $Basket->get('BillingAddress'), $Basket->get('ShippingAddress'), 'billing and shipping address equals');
                $Basket->get('BillingAddress')->mock('CompareAddress', sub {1});
                ok( ! StoreAmazonShippingAddress( $Basket, {} ), 'StoreAmazonShippingAddress without changes does not cause an update.' );
            }
        );
    }
);
